import type { forgotPasswordOperation } from '../../auth/operations/forgotPassword';
import type { loginOperation } from '../../auth/operations/login';
import type { refreshOperation } from '../../auth/operations/refresh';
import type { PayloadRequest } from '../../exports/types';
import type { SanitizedCollectionConfig, TypeWithID } from '../config/types';
import type { createOperation } from './create';
import type { deleteOperation } from './delete';
import type { deleteByIDOperation } from './deleteByID';
import type { findOperation } from './find';
import type { findByIDOperation } from './findByID';
import type { updateOperation } from './update';
import type { updateByIDOperation } from './updateByID';
export type AfterOperationMap<T extends TypeWithID> = {
    create: typeof createOperation;
    delete: typeof deleteOperation;
    deleteByID: typeof deleteByIDOperation;
    find: typeof findOperation<T>;
    findByID: typeof findByIDOperation<T>;
    forgotPassword: typeof forgotPasswordOperation;
    login: typeof loginOperation;
    refresh: typeof refreshOperation;
    update: typeof updateOperation;
    updateByID: typeof updateByIDOperation;
};
export type AfterOperationArg<T extends TypeWithID> = {
    /** The collection which this hook is being run on */
    collection: SanitizedCollectionConfig;
    req: PayloadRequest;
} & ({
    args: Parameters<AfterOperationMap<T>['create']>[0];
    operation: 'create';
    result: Awaited<ReturnType<AfterOperationMap<T>['create']>>;
} | {
    args: Parameters<AfterOperationMap<T>['delete']>[0];
    operation: 'delete';
    result: Awaited<ReturnType<AfterOperationMap<T>['delete']>>;
} | {
    args: Parameters<AfterOperationMap<T>['deleteByID']>[0];
    operation: 'deleteByID';
    result: Awaited<ReturnType<AfterOperationMap<T>['deleteByID']>>;
} | {
    args: Parameters<AfterOperationMap<T>['find']>[0];
    operation: 'find';
    result: Awaited<ReturnType<AfterOperationMap<T>['find']>>;
} | {
    args: Parameters<AfterOperationMap<T>['findByID']>[0];
    operation: 'findByID';
    result: Awaited<ReturnType<AfterOperationMap<T>['findByID']>>;
} | {
    args: Parameters<AfterOperationMap<T>['forgotPassword']>[0];
    operation: 'forgotPassword';
    result: Awaited<ReturnType<AfterOperationMap<T>['forgotPassword']>>;
} | {
    args: Parameters<AfterOperationMap<T>['login']>[0];
    operation: 'login';
    result: Awaited<ReturnType<AfterOperationMap<T>['login']>>;
} | {
    args: Parameters<AfterOperationMap<T>['refresh']>[0];
    operation: 'refresh';
    result: Awaited<ReturnType<AfterOperationMap<T>['refresh']>>;
} | {
    args: Parameters<AfterOperationMap<T>['update']>[0];
    operation: 'update';
    result: Awaited<ReturnType<AfterOperationMap<T>['update']>>;
} | {
    args: Parameters<AfterOperationMap<T>['updateByID']>[0];
    operation: 'updateByID';
    result: Awaited<ReturnType<AfterOperationMap<T>['updateByID']>>;
});
export declare const buildAfterOperation: <T extends TypeWithID = any, O extends keyof AfterOperationMap<T> = keyof AfterOperationMap<T>>(operationArgs: Omit<AfterOperationArg<T>, "req"> & {
    operation: O;
}) => Promise<Awaited<ReturnType<AfterOperationMap<T>[O]>>>;
//# sourceMappingURL=utils.d.ts.map